##  Layers of the SAP LeanIX Meta Model
The layers in the meta model are purely conceptual. They structure your enterprise architecture into logical architecture domains from business strategy down to technical execution. They do not impose any physical or technical separation, they simply help understand and communicate your enterprise architecture. As such, you will not find any references to these layers in the product itself.
  * Business Architecture: Contains fact sheet types organization, business capability, and business context.
  * Application & Data Architecture: Contains fact sheet types data object, application, and interface.
  * Technical Architecture: Contains fact sheet types provider, IT component, and tech category.


The Strategy & Transformation layer spans across the entire meta model and all architecture layers. It contains fact sheet types objective, platform, and initiative.
